/**
 * History:
 * - 2018.03.09 file created, following a restructuring of the previous library.
 */

#include <memory>
#include "xnet/datastructures/stores/MessageStore.hpp"

namespace uu {
namespace net {



MessageStore::
MessageStore(
)
{
}

}
}
